@@ -44,7 +44,7 @@ v_last_partition_created        boolean;
 v_max                           bigint;
 v_native_sub_control            text;
 v_notnull                       boolean;
-v_new_search_path               text := '@extschema@,pg_temp';
+v_new_search_path               text;
 v_old_search_path               text;
 v_parent_owner                  text;
 v_parent_partition_id           bigint;
@@ -242,10 +242,15 @@ ELSE
 END IF;
 
 SELECT current_setting('search_path') INTO v_old_search_path;
+IF length(v_old_search_path) > 0 THEN
+   v_new_search_path := '@extschema@,pg_temp,'||v_old_search_path;
+ELSE
+    v_new_search_path := '@extschema@,pg_temp';
+END IF;
 IF p_jobmon THEN
     SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
-        v_new_search_path := '@extschema@,'||v_jobmon_schema||',pg_temp';
+        v_new_search_path := format('%s,%s',v_jobmon_schema, v_new_search_path);
     END IF;
 END IF;
 EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
@@ -740,6 +745,12 @@ IF p_type = 'native' AND current_setting('server_version_num')::int >= 110000 TH
         , v_parent_schema, v_parent_tablename, v_parent_schema, v_default_partition);
     EXECUTE v_sql;
 
+    IF p_publications IS NOT NULL THEN
+        -- NOTE: Native publication inheritance is only supported on PG14+
+        PERFORM @extschema@.apply_publications(p_parent_table, v_parent_schema, v_default_partition);
+    END IF;
+
+
     IF current_setting('server_version_num')::int >= 120000 AND v_parent_tablespace IS NOT NULL THEN
         -- Tablespace managed via inherit_template_properties() call below if PG11 or earliser
         EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_default_partition, v_parent_tablespace);
